#
# PowerDNS server spec file
#
Summary:		PowerDNS is a Versatile Database Driven Nameserver
Name:			pdns-server
Version:		3.3.1
Release:		2%{dist}
Epoch:			0
License:		GPL
Group:			System Environment/Daemons
URL:			http://www.powerdns.com/
Source0:		http://downloads.powerdns.com/releases/pdns-3.3.1.tar.gz
Patch0:			pdns-3.3-init.patch

Source1:		http://downloads.powerdns.com/documentation/html.tar.gz

BuildRequires:		autoconf automake
BuildRequires:		gcc gcc-c++
BuildRequires:		zlib-devel
BuildRequires:		lua-devel
BuildRequires:		boost-devel >= 1.35.0
BuildRequires:		sqlite-devel >= 3.0.0

Requires:		lua
Requires:		boost-serialization >= 1.35.0
Requires:		boost-program-options >= 1.35.0
Requires:		sqlite >= 3.0.0

Provides:		nameserver
Obsoletes:		pdns-static
Obsoletes:		pdns-server-dnssec-tools

BuildRoot:		%{_tmppath}/%{name}-%{version}-root

%description
PowerDNS is a versatile nameserver which supports a large number
of different backends ranging from simple zonefiles to relational
databases and load balancing/failover algorithms.

This RPM comes with support for MySQL, PostgreSQL, Bind zonefiles and the 'pipe
backend' availible as external packages.

%package		backend-pipe
Summary:		Pipe/coprocess backend for %{name}
Group:			System Environment/Daemons
Requires:		%{name} = %{epoch}:%{version}-%{release}

%description		backend-pipe
This package contains the pipe backend for the PowerDNS nameserver. This
allows PowerDNS to retrieve domain info from a process that accepts
questions on stdin and returns answers on stdout.

%package		backend-geo
Summary:		Geo backend for %{name}
Group:			System Environment/Daemons
Requires:		%{name} = %{epoch}:%{version}-%{release}

%description		backend-geo
This package contains the geo backend for the PowerDNS nameserver. This
backend can be used to distribute queries globally using an IP-address/country
mapping table.

%package		backend-mysql
Summary:		MySQL backend for %{name}
Group:			System Environment/Daemons
Requires:		%{name} = %{epoch}:%{version}-%{release}
Requires:		mysql
BuildRequires:		mysql-devel

%description		backend-mysql
This package contains the MySQL backend for the PowerDNS nameserver.

%package		backend-postgresql
Summary:		postgesql backend for %{name}
Group:			System Environment/Daemons
Requires:		%{name} = %{epoch}:%{version}-%{release}
Requires:		postgresql
BuildRequires:		postgresql-devel

%description		backend-postgresql
This package contains the postgesql backend for the PowerDNS nameserver.

%package		backend-sqlite3
Summary:		sqlite3 backend for %{name}
Group:			System Environment/Daemons
Requires:		%{name} = %{epoch}:%{version}-%{release}

%description		backend-sqlite3
This package contains the sqlite3 backend for the PowerDNS nameserver.

%package		backend-ldap
Summary:		LDAP backend for %{name}
Group:			System Environment/Daemons
Requires:		%{name} = %{epoch}:%{version}-%{release}
Requires:		openldap
BuildRequires:		openldap-devel

%description		backend-ldap
This package contains the LDAP backend for the PowerDNS nameserver.

%package		backend-remote
Summary:		Experimental remotere backend for %{name}
Group:			System Environment/Daemons
Requires:		%{name} = %{epoch}:%{version}-%{release}
%if 0%{?rhel}%{?centos} >= 6
BuildRequires:		libcurl-devel
Requires:		libcurl
%define enable_remotebackend_http --enable-remotebackend-http
%else
%define enable_remotebackend_http %{nil}
%endif

%description		backend-remote
This package contains the remote backend for the PowerDNS nameserver. This
backend provides json based unix socket / pipe / http remoting for powerdns.

%package -n		pdns-tools
Summary:		PowerDNS DNS tools
Group:			Applications/System
Requires:		boost-program-options >= 1.35.0
Conflicts:		%{name} < %{epoch}:%{version}-%{release}
Conflicts:		%{name} > %{epoch}:%{version}-%{release}
Obsoletes:		pdns-server-tools

%description -n		pdns-tools
This package contains the the PowerDNS DNS tools.

%prep
%setup -q -n pdns-3.3.1 -a1
%patch0 -p0 -b .init

%build
%configure \
    --sysconfdir=%{_sysconfdir}/powerdns \
    --libdir=%{_libdir} \
    --with-sqlite3 \
    --with-socketdir=/var/run/pdns-server \
    --with-modules="" \
    --with-dynmodules="pipe geo gmysql gpgsql gsqlite3 ldap remote" \
    --disable-static \
    --enable-tools %{enable_remotebackend_http}
%{__make}

# dirty hack to force immediate binding with hardenend build having
# autocrap's libtool pass the need gcc-specs to linker.
sed -i -e 's! \\\$compiler_flags !&\\\$CFLAGS \\\$LDFLAGS !' libtool

%install
[ "$RPM_BUILD_ROOT" != "/" ] && rm -rf $RPM_BUILD_ROOT

install -d $RPM_BUILD_ROOT%{_sysconfdir}/powerdns/
install -d $RPM_BUILD_ROOT%{_localstatedir}/run/pdns-server

%{__make} DESTDIR=$RPM_BUILD_ROOT install

rm -f $RPM_BUILD_ROOT%{_libdir}/*.la

# fix the config
mv $RPM_BUILD_ROOT%{_sysconfdir}/powerdns/pdns.conf-dist $RPM_BUILD_ROOT%{_sysconfdir}/powerdns/pdns.conf

cat >> $RPM_BUILD_ROOT%{_sysconfdir}/powerdns/pdns.conf << EOF
module-dir=%{_libdir}
socket-dir=/var/run/pdns-server
setuid=powerdns
setgid=powerdns
launch=bind
EOF

chmod 600 $RPM_BUILD_ROOT%{_sysconfdir}/powerdns/pdns.conf

# install sysv scripts
install -d $RPM_BUILD_ROOT%{_initrddir}
install -m755 pdns/pdns $RPM_BUILD_ROOT%{_initrddir}/pdns-server

%clean
[ "$RPM_BUILD_ROOT" != "/" ] && rm -rf $RPM_BUILD_ROOT

%pre
if [ $1 -eq 1 ]; then
    if [ -z "`/usr/bin/id -u powerdns 2>/dev/null`" ]; then
	/usr/sbin/useradd -r -M -d /tmp -s /sbin/nologin -c "PowerDNS User" powerdns 2>&1 || :
    fi
fi

%post
if [ $1 -eq 1 ]; then
    /sbin/chkconfig --add pdns-server
fi

%preun
if [ $1 -eq 0 ]; then
    /sbin/service pdns-server stop >/dev/null 2>&1 || :
    /sbin/chkconfig --del pdns-server
    if [ -d %{_localstatedir}/run/pdns-server ]; then
	rm -rf %{_localstatedir}/run/pdns-server
    fi
    /usr/sbin/userdel powerdns 2>/dev/null || :
fi

%postun
if [ $1 -ge 1 ]; then
    /sbin/service pdns-server condrestart >/dev/null 2>&1
fi

%files
%defattr(-,root,root)
%doc COPYING HACKING INSTALL README html pdns/bind-dnssec.schema.sqlite3.sql
%config(noreplace) %attr(0600,root,root) %{_sysconfdir}/powerdns/pdns.conf
%config(noreplace) %attr(0755,root,root) %{_initrddir}/pdns-server
%dir %{_sysconfdir}/powerdns
%dir %attr(0755,powerdns,powerdns) /var/run/pdns-server
%{_bindir}/pdns_control
%{_bindir}/pdnssec
%{_sbindir}/pdns_server
%{_mandir}/man8/pdns_control.8*
%{_mandir}/man8/pdnssec.8*
%{_mandir}/man8/pdns_server.8*

%files backend-pipe
%defattr(-,root,root)
%{_libdir}/libpipebackend.so

%files backend-geo
%defattr(-,root,root)
%{_libdir}/libgeobackend.so
%doc modules/geobackend/README

%files backend-mysql
%defattr(-,root,root)
%{_libdir}/libgmysqlbackend.so
%doc pdns/no-dnssec.schema.mysql.sql pdns/dnssec.schema.mysql.sql

%files backend-postgresql
%defattr(-,root,root)
%{_libdir}/libgpgsqlbackend.so
%doc pdns/no-dnssec.schema.pgsql.sql pdns/dnssec.schema.pgsql.sql

%files backend-sqlite3
%defattr(-,root,root)
%{_libdir}/libgsqlite3backend.so
%doc pdns/no-dnssec.schema.sqlite3.sql pdns/dnssec.schema.sqlite3.sql

%files backend-ldap
%defattr(-,root,root)
%{_libdir}/libldapbackend.so

%files backend-remote
%defattr(-,root,root)
%{_libdir}/libremotebackend.so

%files -n pdns-tools
%defattr(-,root,root)
%{_bindir}/zone2sql
%{_bindir}/zone2ldap
%{_bindir}/zone2json
 %{_bindir}/dnsreplay
 %{_bindir}/dnsscope
 %{_bindir}/dnswasher
 %{_bindir}/dnstcpbench
 %{_bindir}/dnsbulktest
 %{_bindir}/dnsscan
 %{_bindir}/nproxy
# %{_bindir}/dnsdist
 %{_bindir}/nsec3dig
%{_mandir}/man8/zone2sql.8*
%{_mandir}/man8/zone2ldap.8*
 %{_mandir}/man8/dnsreplay.8*
 %{_mandir}/man8/dnsscope.8*
 %{_mandir}/man8/dnswasher.8*
 %{_mandir}/man1/dnstcpbench.1*

%changelog
* Mon Jan 14 2014 Kees Monshouwer <mind@minshouwer.eu> 3.3.1-2
- Fix pdns-tools dependency problem

* Tue Dec 17 2013 Kees Monshouwer <mind@minshouwer.eu> 3.3.1-1
- Update to 3.3.1

* Mon Jul 08 2013 Kees Monshouwer <mind@monshouwer.eu> 3.3-2
- Add remote backend

* Fri Jul 05 2013 Kees Monshouwer <mind@monshouwer.eu> 3.3-1
- Update to 3.3
- Add geo backend

* Thu Jan 17 2013 Kees Monshouwer <mind@monshouwer.eu> 3.2-1
- Update to 3.2
- Add sqlite3 backend

* Wed Sep 05 2012 Kees Monshouwer <km|monshouwer_com> 3.1-2
- Fix powerdns user and primary group creation
- Improve spec file

* Fri May 04 2012 Kees Monshouwer <km|monshouwer_com> 3.1-1
- Update to 3.1

* Sun Jan 08 2012 Kees Monshouwer <km|monshouwer_com> 3.0.1-1
- Update to 3.0.1

* Fri Jul 22 2011 Kees Monshouwer <km@monshouwer.com> 3.0-1
- Initial build for PowerDNS 3.0
